-- ARCHIVO CON LAS ACTUALIZACIONES DE DATA DE SQL PARA MIGRAR AL NUEVO BUILD DEL NOMBRE DE LA CARPETA
-- DECLARAMOS DOS VARIABLES, UNA CON LA VERSION DE LA QUE PARTIMOS Y OTRA CON LA NUEVA VERSION QUE ESTAMOS APUNTANDO
DECLARE @OLD_DATABASE_BUILD_VERSION VARCHAR(50) = '0.22.0'
DECLARE @NEW_DATABASE_BUILD_VERSION VARCHAR(50) = '0.22.1'

-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
BEGIN TRY
    -- VALIDAMOS QUE LA VERSION EXISTENTE COINCIDE CON NUESTRA NEW_DATABASE_BUILD_VERSION
    IF NOT EXISTS (
        SELECT 1 
            FROM [dbo].[Version] V 
            WHERE V.[BuildVersion] = @OLD_DATABASE_BUILD_VERSION
    )	
        -- LANZAMOS UN MENSAJE DE ERROR INDICANDO QUE LA VERSION ACTUAL NO COINCIDE CON LA OLD_DATABASE_BUILD_VERSION
        RAISERROR('DATABASE_ERROR_INCORRECT_TARGET_VERSION', 16, 16)
        
    -- INICIAMOS LA TRANSACCION
    BEGIN TRANSACTION





    -- AQUI EMPIEZA LA SECCION CON LOS INSERT/UPDATE/DELETE PARA LA NUEVA VERSION

    DELETE FROM [dbo].[CategoryPermissions] WHERE [Category] = 'CATEG_GROUP_CUSTOM_FIELD'
    DELETE FROM [dbo].[CategoryPermissions] WHERE [Category] = 'CATEG_GROUP_ENTITY'
    UPDATE [dbo].[CategoryPermissions] SET [Position] = 20 WHERE [Category] = 'CATEG_GROUP_DICTIONARY'

    UPDATE [dbo].[RolePermission] SET [GroupId] = 'PERM_GROUP_WORD_VIEW' WHERE [GroupId] = 'PERM_GROUP_DICTIONARY_WORD_VIEW'
    UPDATE [dbo].[RolePermission] SET [GroupId] = 'PERM_GROUP_WORD_ADD' WHERE [GroupId] = 'PERM_GROUP_DICTIONARY_WORD_ADD'
    UPDATE [dbo].[RolePermission] SET [GroupId] = 'PERM_GROUP_WORD_EDIT' WHERE [GroupId] = 'PERM_GROUP_DICTIONARY_WORD_EDIT'
    UPDATE [dbo].[RolePermission] SET [GroupId] = 'PERM_GROUP_WORD_DELETE' WHERE [GroupId] = 'PERM_GROUP_DICTIONARY_WORD_DELETE'
    
    UPDATE [dbo].[RolePermissionsGroup] SET [Category] = 'CATEG_GROUP_EVALUATIONFORMAT' WHERE [Category] = 'CATEG_GROUP_CUSTOM_FIELD'
    UPDATE [dbo].[RolePermissionsGroup] SET [Category] = 'CATEG_GROUP_NLU' WHERE [Category] = 'CATEG_GROUP_ENTITY'
    UPDATE [dbo].[RolePermissionsGroup] SET [GroupId] = 'PERM_GROUP_WORD_VIEW' WHERE [GroupId] = 'PERM_GROUP_DICTIONARY_WORD_VIEW'
    UPDATE [dbo].[RolePermissionsGroup] SET [GroupId] = 'PERM_GROUP_WORD_ADD' WHERE [GroupId] = 'PERM_GROUP_DICTIONARY_WORD_ADD'
    UPDATE [dbo].[RolePermissionsGroup] SET [GroupId] = 'PERM_GROUP_WORD_EDIT' WHERE [GroupId] = 'PERM_GROUP_DICTIONARY_WORD_EDIT'
    UPDATE [dbo].[RolePermissionsGroup] SET [GroupId] = 'PERM_GROUP_WORD_DELETE' WHERE [GroupId] = 'PERM_GROUP_DICTIONARY_WORD_DELETE'

    UPDATE [dbo].[RoutePermission] SET [GroupId] = 'PERM_GROUP_WORD_VIEW' WHERE [GroupId] = 'PERM_GROUP_DICTIONARY_WORD_VIEW'
    UPDATE [dbo].[RoutePermission] SET [GroupId] = 'PERM_GROUP_WORD_ADD' WHERE [GroupId] = 'PERM_GROUP_DICTIONARY_WORD_ADD'
    UPDATE [dbo].[RoutePermission] SET [GroupId] = 'PERM_GROUP_WORD_EDIT' WHERE [GroupId] = 'PERM_GROUP_DICTIONARY_WORD_EDIT'
    UPDATE [dbo].[RoutePermission] SET [GroupId] = 'PERM_GROUP_WORD_DELETE' WHERE [GroupId] = 'PERM_GROUP_DICTIONARY_WORD_DELETE'
                                      
    -- AQUI TERMINA LA SECCION CON LOS INSERT/UPDATE/DELETE PARA LA NUEVA VERSION



    

    -- TERMINAMOS LA ACTUALIZACION DE DATA ACTUALIZANDO EL BUILDVERSION
    UPDATE [dbo].[Version] 
        SET [BuildVersion] = @NEW_DATABASE_BUILD_VERSION, 
            [IsRegistered] = 0,
            [TimeStamp] = GETUTCDATE() 
        WHERE [BuildVersion] = @OLD_DATABASE_BUILD_VERSION
    PRINT 'UPDATED_DATABASE_BUILD_VERSION'

    -- COMPLETAMOS LA TRANSACCION
    COMMIT TRANSACTION
END TRY
BEGIN CATCH
    IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

    DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
    DECLARE @Severity integer = ERROR_SEVERITY()
    DECLARE @State integer = ERROR_STATE()

    RAISERROR(@Message, @Severity, @State)
    --RETURN -1
END CATCH



