
GO
PRINT N'Creando [dbo].[WordsByLanguage]...';


GO
CREATE TABLE [dbo].[WordsByLanguage] (
    [Label]    VARCHAR (50)  NULL,
    [Language] VARCHAR (4)   NULL,
    [Word]     VARCHAR (100) NULL
);


GO
PRINT N'Modificando [dbo].[CreateVcc]...';


GO
ALTER PROCEDURE [dbo].[CreateVcc] (
	@VCC Varchar(50) = NULL, 
	@ID Varchar(50) = NULL,
	@Description Varchar(50) = NULL,
	@Type VARCHAR(50) = NULL,
	@TranscriptionDefaultLanguage VARCHAR(25) = NULL,
	@CognitiveEngine VARCHAR(25) = NULL,
	@Country Varchar(50) = NULL,
	@Language Varchar(50) = NULL,
	@TimeZone Varchar(50) = NULL,
	@CreatedDate Datetime = NULL,
	@CreatedByUserId Varchar(50) = NULL,
	@LastModifiedDate Datetime = NULL,
	@LastModifiedByUserId   VARCHAR(50) = NULL,
	@DeleteDataDays         INT = 360
	)
AS
BEGIN
	SET NOCOUNT ON
	BEGIN TRY
    BEGIN TRANSACTION


	INSERT INTO [dbo].[VCC] (
			[VCC], 
			[ID], 
			[Description], 
			[Type], 
			[Country], 
			[TranscriptionDefaultLanguage], 
			[CognitiveEngine], 
			[Language],
			[TimeZone], 
			[CreatedDate], 
			[CreatedByUserId], 
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[DeleteDataDays], 
			[TimeStamp]
			)
	VALUES (
			@VCC, 
			@ID, 
			@Description, 
			@Type, 
			@Country, 
			@TranscriptionDefaultLanguage, 
			@CognitiveEngine, 
			@Language, 
			@TimeZone, 
			@CreatedDate,  
			@CreatedByUserId, 
			@LastModifiedDate, 
			@LastModifiedByUserId, 
			@DeleteDataDays,
			GETUTCDATE()
		)
	
	DECLARE @VCC_SYSTEM       VARCHAR(50) = 'system'

    --INSERTAR ROLES
	
	DECLARE @ROLES TABLE(
    [ID]            VARCHAR(50),
    [Description]   VARCHAR(50),
	[CreatedDate]   DATETIME,
    [CreatedByUserId] VARCHAR(50),
    [LastModifiedDate] DATETIME,
    [LastModifiedByUserId] VARCHAR(50),
	[SystemRole]    BIT,
    [Type]                 VARCHAR(50)
	)
	INSERT INTO @ROLES EXEC [dbo].[GetRoles] @VCC_SYSTEM,'name',''

	IF(EXISTS(SELECT [ID] FROM @ROLES))
	BEGIN
			INSERT INTO [dbo].[Role] (
					[VCC],
					[ID], 
					[Description],
					[CreatedDate], 
					[CreatedByUserId], 
					[LastModifiedDate],
					[LastModifiedByUserId],
					[SystemRole],
					[Type],
					[TimeStamp]
					)
			SELECT @VCC,
				   [ID],
				   [Description],
				   GETUTCDATE(), 
				   [CreatedByUserId],
				   GETUTCDATE(),
				   [LastModifiedByUserId],
				   [SystemRole],
				   [Type],
				   GETUTCDATE()
			FROM @ROLES
     END
	 ELSE
	 BEGIN
	       RAISERROR('SERVER_ERROR_ROLES_NOT_FOUND', 16, 16)
	 END

	--INSERTAR PERMISOS PARA LOS ROLES

	DECLARE @CountLicense INT = 0
	DECLARE @License      VARCHAR(50)
	
	DECLARE @ROLE_PERMISSIONS TABLE(
	 [ID]      VARCHAR(50),
	 [GroupId] VARCHAR(200)
	)
	DECLARE @ROUTE_PERMISSIONS TABLE(
	 [ID]      VARCHAR(50),
	 [Route]   VARCHAR(250),
	 [Level]   VARCHAR(50),
	 [GroupId] VARCHAR(200)
	)

	SET @CountLicense = (SELECT COUNT(*) FROM [dbo].[VCCLicense] (NOLOCK) WHERE [VCC] = @VCC AND [Status] = 1)
	
	IF(@CountLicense>1)
	BEGIN
	    INSERT INTO @ROLE_PERMISSIONS EXEC [dbo].[GetRolePermission] @VCC_SYSTEM,''
		INSERT INTO @ROUTE_PERMISSIONS EXEC [dbo].[GetRoleRoutePermission] @VCC_SYSTEM
	END

	IF(@CountLicense=1)
	BEGIN
	    SET @License = (SELECT Product FROM [dbo].[VCCLicense] (NOLOCK) WHERE [VCC] = @VCC AND [Status] = 1)
	    INSERT INTO @ROLE_PERMISSIONS EXEC [dbo].[GetRolePermission] @VCC_SYSTEM,'', @License
		INSERT INTO @ROUTE_PERMISSIONS EXEC [dbo].[GetRoleRoutePermission] @VCC_SYSTEM,'', @License
	END
	
	INSERT INTO [dbo].[RolePermission] (
			    [VCC], 
				[RoleId], 
				[GroupId],
			    [TimeStamp]
			    ) 
				SELECT 
				@VCC,
				[ID],
				[GroupId],
			    GETUTCDATE()
				FROM @ROLE_PERMISSIONS

	INSERT INTO [dbo].[RoutePermission] (
			[VCC], 
			[ID], 
			[GroupId],
			[Route], 
			[Level], 
			[TimeStamp]
			)
			SELECT 
			@VCC,
			[ID],
			[GroupId],
			[Route],
			[Level],
			GETUTCDATE()
			FROM @ROUTE_PERMISSIONS


    --INSERTAR GRUPOS DE PERMISOS PARA LOS ROLES
	DECLARE @ROLE_PERMISSIONS_GROUP TABLE(
	 [Category] VARCHAR(50),
	 [GroupId]  VARCHAR(200),
	 [Type]     VARCHAR(50)
	)

	INSERT INTO @ROLE_PERMISSIONS_GROUP EXEC [dbo].[GetRolePermissionsGroups] @VCC_SYSTEM

	INSERT INTO [dbo].[RolePermissionsGroup] (
			                              [VCC], 
										  [GroupId], 
										  [Category], 
										  [Type], 
										  [TimeStamp]
										  )
		                                 SELECT 
										 @VCC, 
										 GroupId,
										 Category,
										 [Type], 
										 GETUTCDATE()	
										 FROM @ROLE_PERMISSIONS_GROUP

    --INSERTAR FEELINGS
	INSERT INTO [dbo].[Feeling] (
			                   [VCC], 
							   [Name], 
							   [Description],
							   [CreatedDate], 
							   [CreatedByUserId], 
							   [LastModifiedDate], 
							   [LastModifiedByUserId], 
							   [TimeStamp]
							   )
							   SELECT
							   @VCC,
							   [Name],
							   [Description],
							   GETUTCDATE(),
							   [CreatedByUserId],
							   GETUTCDATE(),
							   [LastModifiedByUserId],
							   GETUTCDATE()	
							   FROM [dbo].[Feeling] (NOLOCK)
							   WHERE [VCC] = @VCC_SYSTEM

    --INSERTAR PROGRAMACION NEUROLINGUISTICA
	INSERT INTO [dbo].[NeuroLinguisticProgramming] (
								[VCC],
								[Name],
								[Description],
								[CreatedDate],
								[CreatedByUserId],
								[LastModifiedDate], 
								[LastModifiedByUserId],
								[TimeStamp]
								)
								SELECT 
								@VCC,
								[Name],
								[Description],
								GETUTCDATE(),
								[CreatedByUserId],
								GETUTCDATE(),
								[LastModifiedByUserId],
								GETUTCDATE()
								FROM [dbo].[NeuroLinguisticProgramming] (NOLOCK)
								WHERE [VCC] = @VCC_SYSTEM
		
   --INSERTAR PALABRAS

   IF(EXISTS(SELECT [Name] FROM [dbo].[Word] (NOLOCK) WHERE [VCC] = @VCC_SYSTEM))
   BEGIN
		   INSERT INTO [dbo].[Word](
					[VCC],
					[NeuroLinguisticProgrammingId],
					[Name],
					[ProcessId],
					[Language],
					[Type],
					[CreatedDate],
					[CreatedByUserId],
					[LastModifiedDate],
					[LastModifiedByUserId],
					[TimeStamp]
					)
				SELECT
				@VCC,
				[NeuroLinguisticProgrammingId],
				[Name],
				[ProcessId],
				[Language],
				[Type],
				GETUTCDATE(),
				[CreatedByUserId],
				GETUTCDATE(),
				[LastModifiedByUserId],
				GETUTCDATE()
			   FROM [dbo].[Word] (NOLOCK)
			   WHERE [VCC] = @VCC_SYSTEM
   END
   ELSE
   BEGIN
	       RAISERROR('SERVER_ERROR_WORD_NOT_FOUND', 16, 16)
   END

   --INSERTAR CATEGORIAS
   INSERT INTO [dbo].[Category] (
			[VCC], 
			[Name], 
			[Description],
			[CreatedDate], 
			[CreatedByUserId], 
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[TimeStamp]
			)
		SELECT 
		@VCC,
		[Name],
		[Description],
		GETUTCDATE(),
		[CreatedByUserId],
		GETUTCDATE(),
		[LastModifiedByUserId],
		GETUTCDATE()
	FROM [dbo].[Category] (NOLOCK)
	WHERE [VCC] = @VCC_SYSTEM

	--INSERTAR AMBIENTES
	IF(@Type <> 'OTHER')
	BEGIN
	  DECLARE @NAME VARCHAR(100)
	  SELECT @NAME = [Word] FROM [dbo].[WordsByLanguage] WHERE [Language] = @Language AND [Label] = 'ENVIRONMENT' 
	  INSERT INTO [dbo].[Environment] (
			[VCC], 
			[Name], 
			[Type],
			[Description],
			[FTPDirectory],
			[ApiHost],
			[ApiPort],
			[ApiUser],
			[DbDisabled],
			[DbServer],
			[DbPort],
			[DbUser], 
			[PbxDisabled],
			[PbxServer],
			[PbxPort],
			[PbxUser],
			[ApiPassword],
			[DbPassword],
			[PbxPassword],
			[CreatedDate],
			[CreatedByUserId], 
			[LastModifiedDate],
			[LastModifiedByUserId], 
			[TimeStamp]
			)
		SELECT 
		@VCC,
		@NAME,
		[Type],
		@NAME,
		[FTPDirectory],
		[ApiHost],
		[ApiPort],
		[ApiUser],
		[DbDisabled],
		[DbServer],
		[DbPort],
		[DbUser],
		[PbxDisabled],
		[PbxServer]	,
		[PbxPort],
		[PbxUser],
		[ApiPassword],
		[DbPassword],
		[PbxPassword],
		GETUTCDATE(),
		[CreatedByUserId],
		GETUTCDATE(),
		[LastModifiedByUserId],
		GETUTCDATE()
	FROM [dbo].[Environment] (NOLOCK)
	WHERE [VCC] = @VCC_SYSTEM

	END


	--INSERTAR PERMISOS PARA CATEGORIAS

	INSERT INTO [dbo].[CategoryPermissions](
			[VCC], 
			[Category], 
			[Position], 
			[TimeStamp]
			)
			SELECT
			@VCC,
		    [Category],
			[Position],
			GETUTCDATE()
			FROM [dbo].[CategoryPermissions] (NOLOCK) 
			WHERE [VCC] = @VCC_SYSTEM
			GROUP BY [Category],[Position]
		  

   --INSERTAR TENANT

   DECLARE @TENANT TABLE(
    [TenantId]     VARCHAR(50),
    [ClientId]     VARCHAR(50),
    [ClientSecret] VARCHAR(50),
    [Resource]     VARCHAR(50)
	)
	
	INSERT INTO @TENANT EXEC [dbo].[GetTenantVCCByVCC] @VCC_SYSTEM
	IF(EXISTS(SELECT [TenantId] FROM @TENANT))
	BEGIN

		INSERT INTO [dbo].[TenantVCC](
		[VCC], 
		[TenantId], 
		[ClientId], 
		[ClientSecret], 
		[Resource], 
		[CreatedDate], 
		[CreatedByUserId], 
		[TimeStamp])
		SELECT 
		@VCC,
		[TenantId],
		[ClientId],
		[ClientSecret],
		[Resource],
		GETUTCDATE(),
		@CreatedByUserId,
		GETUTCDATE()
		FROM @TENANT

	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_TENANT_NOT_FOUND', 16, 16)
	END

	--INSERTAR NLU

	IF(EXISTS(SELECT [Name] FROM [dbo].[NLU] WHERE [IsSystemApp]=1 AND [VCC] = @VCC_SYSTEM))
	BEGIN
		INSERT INTO [dbo].[NLU] (
					[VCC], 
					[Name], 
					[Culture],
					[Description], 
					[AppId], 
					[SubscriptionKey],
					[IsSystemApp], 
					[CreatedDate], 
					[CreatedByUserId], 
					[LastModifiedDate], 
					[LastModifiedByUserId], 
					[TimeStamp],
					[CognitiveEngine]
					)
					SELECT
					@VCC,
					[Name], 
					[Culture],
					[Description], 
					CONCAT(@VCC,'::',[Name]), 
					[SubscriptionKey],
					[IsSystemApp], 
					GETUTCDATE(), 
					[CreatedByUserId], 
					GETUTCDATE(), 
					[LastModifiedByUserId], 
					GETUTCDATE(),
					'RASA'
					FROM [dbo].[NLU]
					WHERE [IsSystemApp]=1 AND [VCC] = @VCC_SYSTEM

        INSERT INTO [dbo].[Intent](
			[VCC], 
			[Name],
			[IntentId],
			[AppId],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[TimeStamp],
			[Status],
			[StatusCode]
			)
			SELECT
			@VCC,
			'Agent',
			'Agent',
			CONCAT(@VCC,'::',[Name]),
			GETUTCDATE(),
			@CreatedByUserId,
			GETUTCDATE(),
			@CreatedByUserId,
			GETUTCDATE(),
			1,
			'AVAILABLE'
			FROM [dbo].[NLU]
					WHERE [IsSystemApp]=1 AND [VCC] = @VCC_SYSTEM
	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_SYSTEM_APPS_SAVING_FAILED', 16, 16)
	END

	--INSERTAR DICCIONARIOS

	IF(EXISTS(SELECT [Name] FROM [dbo].[Dictionary] (NOLOCK) WHERE [VCC] = @VCC_SYSTEM))
	BEGIN 
	INSERT INTO [dbo].[Dictionary] (
			[VCC], 
			[Name], 
			[Description], 
			[Language], 
			[IsSystemDictionary], 
			[CreatedDate], 
			[CreatedByUserId], 
			[TimeStamp]
		)
		SELECT
		    @VCC,
		    [Name],
			[Description],
			[Language],
			[IsSystemDictionary],
			GETUTCDATE(),
			[CreatedByUserId],
			GETUTCDATE()
		FROM [dbo].[Dictionary] (NOLOCK)
		WHERE [VCC] = @VCC_SYSTEM
	END
	ELSE
	BEGIN
	    RAISERROR('SERVER_ERROR_SYSTEM_DICTIONARIES_SAVING_FAILED',16,16)
	END

	--INSERTAR TIPOS DE INTERACCIONES
	IF(EXISTS(SELECT [ID] FROM [dbo].[InteractionType] WHERE [Instance] = @VCC_SYSTEM ))
	BEGIN
	INSERT INTO [dbo].[InteractionType] (
			[Instance],
			[ID],
			[Description]
			)
			SELECT
			@VCC,
			[ID],
		    [Description]
			FROM InteractionType  (NOLOCK)
			WHERE [Instance] = @VCC_SYSTEM
	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_INTERACTION_TYPE_NOT_FOUND',16,16) 
	END

	--INSERTAR GENERIC QUERY

	IF(EXISTS(SELECT [Name] FROM [dbo].[GenericQuery] (NOLOCK) WHERE [VCC] = @VCC_SYSTEM))
	BEGIN
	INSERT INTO [dbo].[GenericQuery]
		(
			[VCC],
			[Name],
			[Description],
			[Query],
			[RawData],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate], 
			[LastModifiedByUserId],
			[Version],
			[TimeStamp]
		)
		SELECT
		@VCC,
		REPLACE([Name], @Language+'_', ''),
		[Description],
		[Query],
		[RawData],
		GETUTCDATE(),
		[CreatedByUserId],
		GETUTCDATE(),
		[LastModifiedByUserId],
		[Version],
		GETUTCDATE()
		FROM [dbo].[GenericQuery] (NOLOCK)
		WHERE [VCC] = @VCC_SYSTEM AND [Name] LIKE @Language + '%'
	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_GENERIC_QUERY_NOT_FOUND',16,16) 
	END

	--INSERTAR  USUARIO AUDITOR SPEECH
	EXEC [dbo].[SaveSpeechAnalyticAuditorUser] @VCC

	--INSERTAR REPORTES
	IF(EXISTS(SELECT [ID] FROM  [dbo].[Report] (NOLOCK) WHERE [VCC] = @VCC_SYSTEM))
	BEGIN
	INSERT INTO [Report] (
			[VCC], 
			[ID], 
			[Description],
			[Type],
            [Procedure], 
			[StartDate],
			[EndDate],
            [Frecuency],
			[HourSpace],
			[ExactTime],
            [Weekday],
			[DayMonth],
			[Summary],
            [Filter], 
			[Email], 
			[CreatedDate],
            [CreatedByUserId],
			[LastModifiedDate],
			[LastModifiedByUserId],
            [TimeStamp]
        )
		SELECT
		        @VCC,
				[ID],
				[Description],
				[Type],
				[Procedure],
				[StartDate],
				[EndDate],
				[Frecuency],
				[HourSpace],
				[ExactTime],
				[Weekday],
				[DayMonth],
				[Summary],
				[Filter],
				[Email],
				GETUTCDATE(),
				@CreatedByUserId,
				GETUTCDATE(),
				@CreatedByUserId,
				GETUTCDATE()
			FROM [dbo].[Report] (NOLOCK)
			WHERE [VCC] = @VCC_SYSTEM

	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_REPORT_NOT_FOUND',16,16) 
	END

	COMMIT TRANSACTION

    END TRY

    BEGIN CATCH

    IF @@TRANCOUNT > 0 
	BEGIN
		ROLLBACK TRANSACTION
		--ELIMINAR LOS REGISTROS SI HA FALLADO
		EXEC [dbo].[RollbackVcc] @VCC
	END

    DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
    DECLARE @Severity integer = ERROR_SEVERITY()
    DECLARE @State integer = ERROR_STATE()

    RAISERROR(@Message, @Severity, @State)
  
    END CATCH
    SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetTemplates]...';


GO
--exec [GetTemplates] 'system','template','name',''
ALTER PROCEDURE [dbo].[GetTemplates] (
	@VCC Varchar(50) = NULL,	
	@Type Varchar(50) = NULL,	
	@SearchCriteria Varchar(50) = NULL,	
	@SearchExpression Varchar(50) = NULL,
	@Language VARCHAR(5) = 'en'
	)
AS
BEGIN
	SET NOCOUNT ON;

	-- CREAMOS LAS CTE QUE USAREMOS PARA RECUPERAR LOS MODELOS DE LAS PLANTILLAS
	WITH CTE_TEMPLATE_NLUS AS (
		SELECT DISTINCT TTI.[VCC]
						, TTI.[TemplateId]
						--, TTI.[TemplateThemeId]
						--, TTI.[ID]
						, N.[AppID]
						, N.[Name]
						, N.[Culture]
			FROM [TemplateThemeItem] TTI (NOLOCK)
			LEFT JOIN [dbo].[GenericQuery] GQ (NOLOCK) 
				ON GQ.[VCC] = TTI.[VCC]
					AND GQ.[Name] = TTI.[ID] 
					AND GQ.[VCC] = TTI.[VCC]
			INNER JOIN [dbo].[NLU] N (NOLOCK) 
				ON N.[VCC] = TTI.[VCC] 
					AND N.[Name] = SUBSTRING(TTI.[ID], 0, CHARINDEX('|', TTI.[ID]))
			WHERE TTI.[VCC] IN (@VCC, 'system')
				AND TTI.[ID] LIKE '%|%'
				AND GQ.[Query] IS NULL
	)

	SELECT
		T.[Type]																'type',
		T.[Name]																'name',
		T.[Description]															'description',
		T.[Template]															'template',
		T.[Category]															'category',
		STUFF((
			SELECT ',' + CTN_INNER.[Culture]
				FROM CTE_TEMPLATE_NLUS CTN_INNER (NOLOCK)
				WHERE CTN_INNER.[TemplateId] = T.[Name]
		FOR XML PATH(''), TYPE).value('.', 'NVARCHAR(MAX)'), 1, 1, '')			'modelLanguages',
		T.[CreatedDate]															'createdDate',
		T.[CreatedByUserId]														'createdByUserId',
		T.[LastModifiedDate]													'lastModifiedDate',
		T.[LastModifiedByUserId]												'lastModifiedByUserId'
	FROM [Template] T (NOLOCK)
	WHERE T.[VCC] IN (@VCC)
		AND T.[Type] = CASE WHEN ISNULL(@Type, '') = '' THEN T.[Type] ELSE @Type END
		AND T.[Type] IN ('custom')
		AND ISNULL(T.[Name], '') LIKE CASE WHEN @SearchCriteria = 'name' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL(T.[Category], '') LIKE CASE WHEN @SearchCriteria = 'category' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL(T.[Description], '') LIKE CASE WHEN @SearchCriteria = 'description' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL(T.[Type], '') LIKE CASE WHEN @SearchCriteria = 'type' THEN '%' + @SearchExpression + '%' ELSE '%' END
		
		UNION 
		
		SELECT
		T.[Type]																'type',
		T.[Name]																'name',
		T.[Description]															'description',
		T.[Template]															'template',
		T.[Category]															'category',
		STUFF((
			SELECT ',' + CTN_INNER.[Culture]
				FROM CTE_TEMPLATE_NLUS CTN_INNER (NOLOCK)
				WHERE CTN_INNER.[TemplateId] = T.[Name]
		FOR XML PATH(''), TYPE).value('.', 'NVARCHAR(MAX)'), 1, 1, '')			'modelLanguages',
		T.[CreatedDate]															'createdDate',
		T.[CreatedByUserId]														'createdByUserId',
		T.[LastModifiedDate]													'lastModifiedDate',
		T.[LastModifiedByUserId]												'lastModifiedByUserId'
	FROM [Template] T (NOLOCK)
	WHERE T.[VCC] IN ('system')
		AND T.[Type] = CASE WHEN ISNULL(@Type, '') = '' THEN T.[Type] ELSE @Type END
		AND T.[Type] IN ('system')
		AND T.[Name] LIKE @Language+'%'
		AND ISNULL(T.[Name], '') LIKE CASE WHEN @SearchCriteria = 'name' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL(T.[Category], '') LIKE CASE WHEN @SearchCriteria = 'category' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL(T.[Description], '') LIKE CASE WHEN @SearchCriteria = 'description' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL(T.[Type], '') LIKE CASE WHEN @SearchCriteria = 'type' THEN '%' + @SearchExpression + '%' ELSE '%' END
		
		
	ORDER BY T.[Name] asc, T.[CreatedDate] desc 

	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[ReportByDetailAgent]...';


GO


ALTER PROCEDURE [dbo].[ReportByDetailAgent] (
	@VCC varchar(50) = NULL, 
	@HistoricCampaign varchar(MAX) = NULL , 
	@Plan varchar(MAX) = NULL,
	@Format varchar(MAX), 
	@StartDate DateTime = NULL , 
	@EndDate DateTime = NULL , 
	@IdAuditor varchar(MAX) = NULL ,
	@IdAgente varchar(MAX) = NULL
) AS
  DECLARE @cols varchar(max) 
  DECLARE @query varchar(max)
  
  -- ReportByDetailAgent 'allegro','entrantes','Plan_2_nov01-0356','nov01-0356','20191001','20191201','isidoro','icagente3'
  SET NOCOUNT ON

  SELECT
    * INTO #TempEvaluationResult
  FROM (
  SELECT
	EP.[Instance]														'VCC',
    EP.Description														AS 'DescriptionPlan',
    EF.Description														AS 'DescriptionFormat',
    (
		GP.Description
		+ '-' 
		+ SGP.Description
		+ '-' 
		+ A.Title
	)																	AS 'Ability', --Collate SQL_Latin1_General_CP1253_CI_AI
    ER.AgentDescription,
    ER.CampaignDescription,
    ER.IdInteraction,
    ISNULL(ER.Qualification, 0)											AS 'Qualification',
	AEP.[AutomaticScore],
	AEP.[ManualScore],
	--Format(ER.EvaluationDate, 'dd/MM/yyyy hh:mm:ss')					AS 'EvaluationDate',
	--CAST(Format(AEP.[TimeStamp], 'yyyy-MM-dd hh:mm:ss') AS DATETIME)					AS 'EvaluationDate',
	AEP.[TimeStamp] AS 'EvaluationDate',
    ER.IdAuditor,
	EP.Evaluation_Mode	
  FROM EvaluationResult (NOLOCK) ER
  INNER JOIN EvaluationFormat EF
    ON ER.IdEvaluationFormat = EF.ID
  INNER JOIN Ability (NOLOCK) A
    ON A.[Instance] = ER.[Instance]
		AND A.ID = ER.IdAbility
  INNER JOIN EvaluationPlan (NOLOCK) EP
    ON EP.ID = ER.IdEvaluationPlan
	INNER JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
		ON AEP.[Instance] = ER.[Instance]
			AND AEP.[IdEvaluationPlan] =  ER.[IdEvaluationPlan]
			AND AEP.[IdInteraction] = ER.[IdInteraction]
			AND AEP.[IdAuditor] =  ER.[IdAuditor]
  LEFT JOIN [Group] (NOLOCK) GP
    ON GP.ID = ER.IdGroup
  LEFT JOIN SubGroup (NOLOCK) SGP
    ON SGP.ID = ER.IdSubGroup
  WHERE 
	ER.Instance LIKE CASE
		WHEN @VCC IS NOT NULL THEN @VCC
		ELSE ER.Instance
	  END
  AND 
	EF.Description IN(SELECT [Value] FROM [dbo].[Split](IIF(@Format IS NULL,EF.Description,@Format),','))
  AND 
	EP.Description IN(SELECT [Value] FROM [dbo].[Split](IIF(@Plan IS NULL,EP.Description,@Plan),','))
  AND 
    ER.CampaignDescription IN(SELECT [Value] FROM [dbo].[Split](IIF(@HistoricCampaign IS NULL,ER.CampaignDescription,@HistoricCampaign),','))
  AND 
    ER.AgentDescription IN(SELECT [Value] FROM [dbo].[Split](IIF(@IdAgente IS NULL,ER.AgentDescription,@IdAgente),','))
	
  AND 
    ER.IdAuditor IN(SELECT [Value] FROM [dbo].[Split](IIF(@IdAuditor IS NULL,ER.IdAuditor,@IdAuditor),','))

  AND AEP.[TimeStamp] >=
                          CASE
                            WHEN @StartDate IS NOT NULL THEN @StartDate
                            ELSE '19800101'
                          END
  AND AEP.[TimeStamp] <
                         CASE
                           WHEN @EndDate IS NOT NULL THEN @EndDate + ' 23:59'
                           ELSE '20500101'
                         END
  --AND EP.[Status] = 7
  AND AEP.[Completed] = 1
	) a

	--select * from #TempEvaluationResult ORDER BY IdInteraction


  SET @cols = STUFF((SELECT DISTINCT
    ',' + QUOTENAME(Ability) 
  FROM #TempEvaluationResult
  FOR xml PATH (''), TYPE)
  .value('.', 'varchar(Max)')
  , 1, 1, '')

  --Select @cols
  IF @cols IS NOT NULL
  BEGIN

    DECLARE @type varchar(max)=(Select Top 1 Evaluation_Mode From #TempEvaluationResult)

    DECLARE @Total varchar(max) = STUFF((SELECT DISTINCT
      '+ ISNULL(' + QUOTENAME(Ability) + ',0)'
    FROM #TempEvaluationResult
    FOR xml PATH (''), TYPE)
    .value('.', 'varchar(Max)')
    , 1, 1, '')
    --SELECT @type
	If @type = 'M'
	BEGIN
    SET @query = ' 
				Select p.[VCC]							AS [VCC],
						p.DescriptionPlan				As [EVALUATION_PLAN],
						p.DescriptionFormat				As [EVALUATION_FORMAT],
						p.AgentDescription				As [AGENT],
  						p.CampaignDescription			As [CAMPAIGN],
						p.IdInteraction					As [INTERACTION],
						p.EvaluationDate				As [EVALUATION_DATE],
						p.IdAuditor						As [AUDITOR],
						InteractionDuration				as [DURATION_TIME], 
						null							As [PHONE],
						InteractionDateStart			As [START_DATE],
						null							As [CATEGORY],
						(' + @Total + ')				As COLUMN_TOTAL_SCORE, 
						p.[AutomaticScore]				AS COLUMN_AUTOMATIC_SCORE,
						p.[ManualScore]					AS COLUMN_MANUAL_SCORE,
						' + @cols + ' 
					from 
				( select VCC,
							DescriptionPlan,
						  DescriptionFormat,
						  Ability,
						  AgentDescription,
						  CampaignDescription,
						  IdInteraction,
						  EvaluationDate,
						  Qualification,
						  AutomaticScore,
						  ManualScore,
						  IdAuditor			
					from #TempEvaluationResult
			   ) x
				pivot 
				( 
					 max(Qualification)
					for Ability in (' + @cols + ')
				) p 
				Left Join (
				Select Distinct IdInteraction,InteractionDuration,InteractionDateStart From InteractionEvaluationPlan (Nolock) 
				) as A On
				A.IdInteraction = p.IdInteraction '
    END
	ELSE 
	BEGIN
    SET @query = ' 
				Select p.[VCC]							AS [VCC],
						p.DescriptionPlan				As [EVALUATION_PLAN],
						p.DescriptionFormat				As [EVALUATION_FORMAT],
						p.AgentDescription				As [AGENT],
  						p.CampaignDescription			As [CAMPAIGN] ,
						p.IdInteraction					As [INTERACTION] ,
						p.EvaluationDate				As [EVALUATION_DATE],
						p.IdAuditor						As [AUDITOR],
						A.DurationTime					as [DURATION_TIME],
						A.Number						As [PHONE] ,
						A.StartDate						As [START_DATE] ,
						A.Category1						As [CATEGORY] ,
						(' + @Total + ')				As COLUMN_TOTAL_SCORE,
						p.[AutomaticScore]				AS COLUMN_AUTOMATIC_SCORE,
						p.[ManualScore]					AS COLUMN_MANUAL_SCORE,
						' + @cols + ' 
					from ( 
						select VCC,
								DescriptionPlan,
								DescriptionFormat,
								Ability,
								AgentDescription,
								CampaignDescription,
								IdInteraction,
								EvaluationDate,
								Qualification,
								AutomaticScore,
								ManualScore,
								IdAuditor			
							from #TempEvaluationResult
					) x pivot 
					( 
						 max(Qualification)
						for Ability in (' + @cols + ')
					) p 
					LEFT Join Audio as A 
						On A.[VCC] = p.[VCC]
							AND A.ID = p.IdInteraction'
	END
	--Print(@query)
    EXECUTE (@query)
    DROP TABLE #TempEvaluationResult
  END
  ELSE
  BEGIN
    SELECT
						''				As [EVALUATION_PLAN],
						''				As [EVALUATION_FORMAT],
						''				As [AGENT],
  						''			    As [CAMPAIGN] ,
						''			 	As [INTERACTION] ,
						''				As [EVALUATION_DATE],
						''				As [AUDITOR]
  END
  
  SET NOCOUNT OFF
GO
PRINT N'Modificando [dbo].[ReportBySummaryAgent]...';


GO


ALTER PROCEDURE [dbo].[ReportBySummaryAgent] (
	@VCC varchar(50) = NULL, 
	@HistoricCampaign varchar(MAX) = NULL, 
	@Plan varchar(MAX) = NULL,
	@Format varchar(MAX) , 
	@StartDate DateTime = NULL , 
	@EndDate DateTime = NULL , 
	@IdAuditor varchar(MAX) = NULL ,
	@IdAgente varchar(MAX) = NULL
) AS
  DECLARE @cols varchar(max)
  DECLARE @query varchar(max)
  --ReportBySummaryAgent 'allegro','entrantes',NULL,'nov01-0356',NULL,NULL,NULL,NULL
  --SET @Format = 'nov01-0356'
  SET NOCOUNT ON
  
  SELECT
    * INTO #TempEvaluationResult
  FROM (
  SELECT
    EP.Description AS 'DescriptionPlan',
    EF.Description AS 'DescriptionFormat',
    GP.Description + '-' + SGP.Description + '-' + A.Title AS 'Ability',
    ER.AgentDescription,
    ER.CampaignDescription,
    ER.IdInteraction,
    ER.Qualification,
    Format(ER.EvaluationDate, 'dd/MM/yyyy hh:mm:ss') AS 'EvaluationDate',
    ER.IdAuditor,
    EP.Evaluation_Mode
  FROM EvaluationResult (NOLOCK) ER
  LEFT JOIN EvaluationFormat (NOLOCK) EF
    ON ER.IdEvaluationFormat = EF.ID
  LEFT JOIN Ability (NOLOCK) A
    ON A.ID = ER.IdAbility
  LEFT JOIN EvaluationPlan (NOLOCK) EP
    ON EP.ID = ER.IdEvaluationPlan
  LEFT JOIN [Group] (NOLOCK) GP
    ON GP.ID = ER.IdGroup
  LEFT JOIN SubGroup SGP (NOLOCK)
    ON SGP.ID = ER.IdSubGroup
  WHERE 
   EF.Description IN(SELECT [Value] FROM [dbo].[Split](IIF(@Format IS NULL,EF.Description,@Format),','))
  AND ER.Instance LIKE CASE
    WHEN @VCC IS NOT NULL THEN @VCC
    ELSE ER.Instance
  END
  AND 
  EP.Description IN(SELECT [Value] FROM [dbo].[Split](IIF(@Plan IS NULL,EP.Description,@Plan),','))
  AND
  ER.CampaignDescription IN(SELECT [Value] FROM [dbo].[Split](IIF(@HistoricCampaign IS NULL,ER.CampaignDescription,@HistoricCampaign),','))
  AND 
  ER.AgentDescription IN(SELECT [Value] FROM [dbo].[Split](IIF(@IdAgente IS NULL,ER.AgentDescription,@IdAgente),','))
  AND 
  ER.IdAuditor IN(SELECT [Value] FROM [dbo].[Split](IIF(@IdAuditor IS NULL,ER.IdAuditor,@IdAuditor),','))
  AND ER.EvaluationDate >=
                          CASE
                            WHEN @StartDate IS NOT NULL THEN @StartDate
                            ELSE '19800101'
                          END
  AND ER.EvaluationDate <
                         CASE
                           WHEN @EndDate IS NOT NULL THEN @EndDate + ' 23:59'
                           ELSE '20500101'
                         END
	) a

	
  SET @cols = STUFF((SELECT DISTINCT
    ',' + QUOTENAME(Ability)
  FROM #TempEvaluationResult
  FOR xml PATH (''), TYPE)
  .value('.', 'varchar(Max)')
  , 1, 1, '')
  
  IF @cols IS NOT NULL
  BEGIN
    ------
    DECLARE @type varchar(max) = (SELECT TOP 1
      Evaluation_Mode
    FROM #TempEvaluationResult)
	-------
    DECLARE @Total varchar(max) = STUFF((SELECT DISTINCT
      '+ ISNULL(' + QUOTENAME(Ability) + ',0)'
    FROM #TempEvaluationResult
    FOR xml PATH (''), TYPE)
    .value('.', 'varchar(Max)')
    , 1, 1, '')    
	-- ROUND(AVG(CAST(ER.Qualification AS float)), 2) AS 'Qualification',
    DECLARE @colavg varchar(max) = STUFF((SELECT DISTINCT
      ', ROUND(AVG(CAST(q.' + QUOTENAME(Ability) + ' AS float)), 2) As [' + Ability + ' Promedio]'
    FROM #TempEvaluationResult
    FOR xml PATH (''), TYPE)
    .value('.', 'varchar(Max)')
    , 1, 1, '')
	
	--SELECT @colavg
    IF @type = 'M'
    BEGIN
      SET @query = ' 
				Select 
				q.DescriptionPlan As   [EVALUATION_PLAN] ,
				q.DescriptionFormat As [EVALUATION_FORMAT] ,
				q.AgentDescription As  [AGENT] ,
				q.CampaignDescription As [CAMPAIGN] ,
				count(q.IdInteraction) As [AUDITS],
				sum(q.DurationTime) As [DURATION_TIME],
				ROUND(AVG(CAST(q.Note AS float)), 2) As [AVERAGE_SCORE],
				' + @colavg + ' From
				(Select p.DescriptionPlan,p.DescriptionFormat,p.AgentDescription,
  				p.CampaignDescription,p.IdInteraction,p.EvaluationDate,p.IdAuditor,InteractionDuration as DurationTime, 
				null As Number,InteractionDateStart As StartDate,null As Category1,(' + @Total + ') As Note, ' + @cols + ' from 
				( select DescriptionPlan,
						  DescriptionFormat,
						  Ability,
						  AgentDescription,
						  CampaignDescription,
						  IdInteraction,
						  EvaluationDate,
						  Qualification,
						  IdAuditor			
					from #TempEvaluationResult
			   ) x
				pivot 
				( 
					 max(Qualification)
					for Ability in (' + @cols + ')
				) p 
				Left Join (
				Select Distinct IdInteraction,InteractionDuration,InteractionDateStart From InteractionEvaluationPlan (Nolock)
				) as A On
				A.IdInteraction=p.IdInteraction)q
				Group By 
				q.DescriptionPlan,q.DescriptionFormat,q.AgentDescription,q.CampaignDescription
				'
    END
    ELSE
    BEGIN
      SET @query = '
	
			    Select 
				q.DescriptionPlan As   [EVALUATION_PLAN] ,
				q.DescriptionFormat As [EVALUATION_FORMAT] ,
				q.AgentDescription As  [AGENT] ,
				q.CampaignDescription As [CAMPAIGN] ,
			    count(q.IdInteraction) As [AUDITS],
				sum(q.DurationTime) As [DURATION_TIME],
				ROUND(AVG(CAST(q.Note AS float)), 2) As [AVERAGE_SCORE],
				' + @colavg + '
				From 
				(Select p.DescriptionPlan,p.DescriptionFormat,p.AgentDescription,
  				p.CampaignDescription,p.IdInteraction,p.EvaluationDate,p.IdAuditor,
				A.DurationTime,A.Number,A.StartDate,A.Category1,(' + @Total + ') As Note, ' + @cols + ' from 
				( select DescriptionPlan,
						  DescriptionFormat,
						  Ability,
						  AgentDescription,
						  CampaignDescription,
						  IdInteraction,
						  EvaluationDate,
						  Qualification,
						  IdAuditor			
					from #TempEvaluationResult
			   ) x
				pivot 
				( 
					 max(Qualification)
					for Ability in (' + @cols + ')
				) p 
				Left Join Audio as A On
				A.ID=p.IdInteraction)q
				Group By 
				q.DescriptionPlan,q.DescriptionFormat,q.AgentDescription,q.CampaignDescription'
    END
    --Print(@query)
    EXECUTE (@query)
    --Select * From @query
	

    DROP TABLE #TempEvaluationResult
  END
  ELSE
  BEGIN
    DROP TABLE #TempEvaluationResult
    SELECT
						''				As [EVALUATION_PLAN],
						''				As [EVALUATION_FORMAT],
						''				As [AGENT],
  						''			    As [CAMPAIGN] 
  END
  
  SET NOCOUNT OFF
GO
PRINT N'Actualizando [dbo].[SaveVcc]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveVcc]';


GO
PRINT N'Actualización completada.';


GO
