IF EXISTS (select top 1 1 from [dbo].[EvaluationReview])
    RAISERROR (N'Se detectaron filas. La actualización del esquema va a terminar debido a una posible pérdida de datos.', 16, 127) WITH NOWAIT

GO
/*
Se está quitando la columna [dbo].[EvaluationReviewCommitment].[EvaluationReviewId]; puede que se pierdan datos.
*/

IF EXISTS (select top 1 1 from [dbo].[EvaluationReviewCommitment])
    RAISERROR (N'Se detectaron filas. La actualización del esquema va a terminar debido a una posible pérdida de datos.', 16, 127) WITH NOWAIT

GO
PRINT N'Quitando [dbo].[DF_EvaluationReviewCommitment_ID]...';


GO
ALTER TABLE [dbo].[EvaluationReviewCommitment] DROP CONSTRAINT [DF_EvaluationReviewCommitment_ID];


GO
PRINT N'Modificando [dbo].[EvaluationReview]...';


GO
ALTER TABLE [dbo].[EvaluationReview] DROP COLUMN [Id];


GO
PRINT N'Iniciando recompilación de la tabla [dbo].[EvaluationReviewCommitment]...';


GO
BEGIN TRANSACTION;

SET TRANSACTION ISOLATION LEVEL SERIALIZABLE;

SET XACT_ABORT ON;

CREATE TABLE [dbo].[tmp_ms_xx_EvaluationReviewCommitment] (
    [VCC]                VARCHAR (50)  NOT NULL,
    [ID]                 VARCHAR (50)  CONSTRAINT [DF_EvaluationReviewCommitment_ID] DEFAULT (newid()) NOT NULL,
    [LargeInteractionId] VARCHAR (255) NOT NULL,
    [EvaluationPlanId]   VARCHAR (50)  NULL,
    [InteractionId]      VARCHAR (50)  NULL,
    [SupervisorId]       VARCHAR (50)  NULL,
    [AgentId]            VARCHAR (50)  NOT NULL,
    [Commitment]         VARCHAR (50)  NULL,
    [CreatedDate]        DATETIME      NULL,
    [CreatedUserId]      VARCHAR (50)  NULL,
    [LastModifiedDate]   DATETIME      NULL,
    [LastModifiedUserId] VARCHAR (50)  NULL,
    [Timestamp]          DATETIME      NULL
);

IF EXISTS (SELECT TOP 1 1 
           FROM   [dbo].[EvaluationReviewCommitment])
    BEGIN
        INSERT INTO [dbo].[tmp_ms_xx_EvaluationReviewCommitment] ([VCC], [ID], [LargeInteractionId], [AgentId], [Commitment], [CreatedDate], [CreatedUserId], [LastModifiedDate], [LastModifiedUserId], [Timestamp])
        SELECT [VCC],
               [ID],
               [LargeInteractionId],
               [AgentId],
               [Commitment],
               [CreatedDate],
               [CreatedUserId],
               [LastModifiedDate],
               [LastModifiedUserId],
               [Timestamp]
        FROM   [dbo].[EvaluationReviewCommitment];
    END

DROP TABLE [dbo].[EvaluationReviewCommitment];

EXECUTE sp_rename N'[dbo].[tmp_ms_xx_EvaluationReviewCommitment]', N'EvaluationReviewCommitment';

COMMIT TRANSACTION;

SET TRANSACTION ISOLATION LEVEL READ COMMITTED;


GO
PRINT N'Modificando [dbo].[GetEvaluationReviewCommitments]...';


GO
ALTER PROCEDURE [dbo].[GetEvaluationReviewCommitments] (
	@VCC Varchar(50) = NULL, 
	@EvaluationPlanId VARCHAR(50) = NULL,
	@InteractionId VARCHAR(50) = NULL,
	@SupervisorId VARCHAR(50) = NULL,
	@AgentId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- SELECCIONAMOS LOS CAMPOS DE LA TABLA EVALUATION-REVIEW-COMMITMENT
	SELECT ERC.[EvaluationPlanId]										'evaluationPlanId',
			ERC.[ID]													'id',
			AEP.[Score]													'score',
			ERC.[SupervisorId]											'supervisorId',
			CONCAT(U2.[FirstName], ' ', ISNULL(U2.[LastName], ''))		'supervisorName',
			ERC.[LargeInteractionId]									'largeInteractionId',
			ERC.[AgentId]												'agentId',
			CONCAT(U1.[FirstName], ' ', ISNULL(U1.[LastName], ''))		'agentName',
			ERC.[Commitment]											'commitment',
			ERC.[CreatedDate]											'eventDate',
			ERC.[CreatedDate]											'createdDate'
		FROM [dbo].[EvaluationReviewCommitment] ERC (NOLOCK) 
		LEFT JOIN [dbo].[User] U1 (NOLOCK)
			ON U1.[VCC] = ERC.[VCC]
				AND U1.[ID] = ERC.[AgentId]
		INNER JOIN [dbo].[User] U2 (NOLOCK)
			ON U2.[VCC] = ERC.[VCC]
				AND U2.[ID] = ERC.[SupervisorId]
		INNER JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
			ON AEP.[Instance] = ERC.[VCC]
				AND AEP.[IdEvaluationPlan] = ERC.[EvaluationPlanId]
				AND AEP.[IdInteraction] = ERC.[InteractionId]
				AND AEP.[IdAuditor] = ERC.[SupervisorId]
				AND AEP.[IdAgent] = ERC.[AgentId]
		WHERE ERC.[VCC] = @VCC
			AND ERC.[EvaluationPlanId] =  ISNULL(@EvaluationPlanId, ERC.[EvaluationPlanId])
			AND ERC.[InteractionId] = ISNULL(@InteractionId, ERC.[InteractionId])
			AND ERC.[SupervisorId] = ISNULL(@SupervisorId, ERC.[SupervisorId])
			AND ERC.[AgentId] = ISNULL(@AgentId, ERC.[AgentId])
		ORDER BY [ERC].[CreatedDate] DESC

	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[SaveEvaluationReview]...';


GO
ALTER PROCEDURE [dbo].[SaveEvaluationReview] (
	@VCC VARCHAR(50) = NULL, 
	@EvaluationPlanId VARCHAR(50) = NULL,
	@InteractionId VARCHAR(50) = NULL,
	@SupervisorId VARCHAR(50) = NULL,
	@Review VARCHAR(500) = NULL,
	@SaveUserId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- ACTUALIZAMOS EL REGISTRO CORRESPONDIENTE A LA REVISION
	UPDATE [dbo].[EvaluationReview]
		SET [Review] = @Review,
			[LastModifiedDate] = GETUTCDATE(),
			[LastModifiedUserId] = @SaveUserId,
			[Timestamp] = GETUTCDATE()
		WHERE [VCC] = @VCC
			AND [EvaluationPlanId] = @EvaluationPlanId
			AND [InteractionId] = @InteractionId
			AND [SupervisorId] = @SupervisorId

	-- SI NO SE ACTUALIZO NINGUN REGISTRO, LO INSERTAMOS
	IF @@ROWCOUNT = 0
	BEGIN
		-- 
		INSERT INTO [dbo].[EvaluationReview] (
				[VCC],
				[EvaluationPlanId],
				[InteractionId],
				[SupervisorId],
				[Review],
				[CreatedDate],
				[CreatedUserId],
				[Timestamp]
			) VALUES (
				@VCC,
				@EvaluationPlanId,
				@InteractionId,
				@SupervisorId,
				@Review,
				GETUTCDATE(),
				@SaveUserId,
				GETUTCDATE()
			)
	END

	-- RETORNAMOS EL REGISTRO INSERTADO/ACTUALIZADO
    SELECT ER.[VCC]													'vcc',
			ER.[EvaluationPlanId]									'evaluationPlanId',
			ER.[InteractionId]										'interactionId',
			ER.[SupervisorId]										'supervisorId',
			ER.[Review]												'review'
		FROM [dbo].[EvaluationReview] ER (NOLOCK) 
		WHERE ER.[VCC] = @VCC
			AND ER.[EvaluationPlanId] = @EvaluationPlanId
			AND ER.[InteractionId] = @InteractionId
			AND ER.[SupervisorId] = ISNULL(@SupervisorId, ER.[SupervisorId])
	
	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[SaveEvaluationReviewCommitment]...';


GO
ALTER PROCEDURE [dbo].[SaveEvaluationReviewCommitment] (
	@VCC VARCHAR(50) = NULL, 
	@Id VARCHAR(50) = NULL,
	@LargeInteractionId VARCHAR(255) = NULL,
	@EvaluationPlanId VARCHAR(50) = NULL,
	@InteractionId VARCHAR(50) = NULL,
	@SupervisorId VARCHAR(50) = NULL,
	@AgentId VARCHAR(50) = NULL,
	@Commitment VARCHAR(500) = NULL,
	@SaveUserId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- ACTUALIZAMOS EL REGISTRO CORRESPONDIENTE A LA REVISION
	UPDATE [dbo].[EvaluationReviewCommitment]
		SET [Commitment] = @Commitment,
			[LastModifiedDate] = GETUTCDATE(),
			[LastModifiedUserId] = @SaveUserId,
			[Timestamp] = GETUTCDATE()
		WHERE [VCC] = @VCC
			AND [EvaluationPlanId] = @EvaluationPlanId
			AND [InteractionId] = @InteractionId
			AND [SupervisorId] = @SupervisorId
			AND [ID] = @Id
			
	-- SI NO SE ACTUALIZO NINGUN REGISTRO, LO INSERTAMOS
	IF @@ROWCOUNT = 0
	BEGIN
		-- 
		INSERT INTO [dbo].[EvaluationReviewCommitment] (
				[VCC],
				[LargeInteractionId],
				[EvaluationPlanId],
				[InteractionId],
				[SupervisorId],
				[AgentId],
				[Commitment],
				[CreatedDate],
				[CreatedUserId],
				[Timestamp]
			) VALUES (
				@VCC,
				@LargeInteractionId,
				@EvaluationPlanId,
				@InteractionId,
				@SupervisorId,
				@AgentId,
				@Commitment,
				GETUTCDATE(),
				@SaveUserId,
				GETUTCDATE()
			)
	END

	-- 
    SELECT 1 AS 'result'
	
	SET NOCOUNT OFF
END
GO
PRINT N'Modificando [dbo].[GetAllegroRole]...';


GO

ALTER PROCEDURE [dbo].[GetAllegroRole]
(
	@IP				VARCHAR(50),
	@VCC			VARCHAR(50),
	@RoleId			VARCHAR(50),
	@Type			INT
)
AS
BEGIN
	DECLARE @SQL VARCHAR(MAX)
	
	IF(@Type = 0)
	BEGIN
		SET @SQL = '
		SELECT TOP 1 ''' + @VCC + '''				''vcc'',
					 [Id]
		FROM [' + @Ip + ']' + '.mmprodat.dbo.[Group] (NOLOCK)
		WHERE (
				[VCC] = ''' + @VCC + '''
				OR
				[VCC] = ''system''
			)
			AND [Id] = ''' + @RoleId + '''
		'
	END
	ELSE
	BEGIN
		SET @SQL = '
		SELECT TOP 1 ''' + @VCC + '''				''vcc'',
					 [Id]
		FROM mmprodat.dbo.[Group] (NOLOCK)
		WHERE
			(
				[VCC] = ''' + @VCC + '''
				OR
				[VCC] = ''system''
			)
			AND [Id] = ''' + @RoleId + '''
		'
	END
	EXEC(@SQL)
END
GO
PRINT N'Modificando [dbo].[GetAllegroSupervisors]...';


GO
ALTER PROCEDURE [dbo].[GetAllegroSupervisors]
(
	@IP				VARCHAR(50),
	@VCC			VARCHAR(50),
	@Type			BIT
)
AS
BEGIN
	-- ESTE SP RETORNA LA LISTA DE SUPERVISORES DE UN VCC DE TIPO ALLEGRO/OCC CON SUS WORKGROUPS DE AGENTES

	-- DECLARAMOS VARIABLES PARA ARMAR LA CONSULTA
	DECLARE @VCC_TYPE VARCHAR(25) = NULL
	DECLARE @SQL VARCHAR(MAX) = NULL
	DECLARE @TABLE_MMPRODAT VARCHAR(100) = NULL

	-- INDETIFICAMOS EL TIPO DE VCC
	SELECT @VCC_TYPE = V.[Type] 
		FROM [dbo].[VCC] V (NOLOCK) 
		WHERE V.[VCC] = @VCC

	-- EL TYPE 0 INDICA QUE LAS TABLAS SE ENCUENTRAN EN UN SERVIDOR EXTERNO
	IF @Type = 0
	BEGIN  
		SET @TABLE_MMPRODAT = '[' + @Ip + ']' + '.[MMProDat].[dbo].'
	END
	ELSE IF(@Type = 1) 
	BEGIN
		SET @TABLE_MMPRODAT = '[MMProDat].[dbo].'
	END
	
	--
	IF @VCC_TYPE = 'ALLEGRO'
	BEGIN
		-- ARMAMOS LA CONSULTA PRINCIPAL
		/*
		SET @SQL = '
			SELECT U.[VCC]					''vcc'',
					U.[Id]					''userId'',
					U.[Name]				''userName'',
					SWG.[CampaignId]		''campaignId'',
					SWG.[WorkgroupId]		''workGroupId''
				FROM ' + @TABLE_MMPRODAT + '[SupervisorWorkgroup] SWG (NOLOCK)
				INNER JOIN ' + @TABLE_MMPRODAT + '[User] U (NOLOCK)
					ON U.[VCC] = SWG.[VCC]
						AND U.[Id] = SWG.[SupervisorId]
				WHERE SWG.[VCC] = ''' + @VCC + ''' '
		*/
		SET @SQL = '
			SELECT U.[VCC]					''vcc'',
					U.[Id]					''userId'',
					U.[Name]				''userName'',
					UC.[CampaignId]			''campaignId'',
					SWG.[WorkgroupId]		''workGroupId''
				FROM ' + @TABLE_MMPRODAT + '[User] U (NOLOCK)
				LEFT JOIN ' + @TABLE_MMPRODAT + '[UserCampaign] UC (NOLOCK)
					ON UC.[VCC] = U.[VCC]
						AND UC.[UserId] = U.[Id]
				LEFT JOIN ' + @TABLE_MMPRODAT + '[SupervisorWorkgroup] SWG (NOLOCK)
					ON SWG.[VCC] = U.[VCC] 
						AND SWG.[SupervisorId] = U.[Id] 
						AND SWG.[CampaignId] = UC.[CampaignId]
				WHERE U.[VCC] = ''' + @VCC + ''' 
					AND U.[UserGroup] = ''supervisor'' '
	END
	ELSE IF @VCC_TYPE = 'OCC'
	BEGIN
		SET @SQL = '
			SELECT U.[VCC]					''vcc'',
					U.[Id]					''userId'',
					U.[Name]				''userName'',
					--U.[UserGroup],
					UC.[CampaignId]			''campaignId'',
					SW.[WorkgroupId]		''workGroupId''
				FROM ' + @TABLE_MMPRODAT + '[User] U (NOLOCK) 
				INNER JOIN ' + @TABLE_MMPRODAT + '[GroupApplication] GA (NOLOCK)
					ON GA.[VCC] = U.[VCC]
						AND GA.[GroupId] = U.[UserGroup] 
				LEFT JOIN ' + @TABLE_MMPRODAT + '[UserCampaign] UC (NOLOCK) 
					ON UC.[VCC] = UC.[VCC]
						AND UC.[UserId] = U.[Id]
				LEFT JOIN ' + @TABLE_MMPRODAT + '[SupervisorWorkgroup] SW (NOLOCK)
					ON SW.[VCC] = U.[VCC]
						AND SW.[SupervisorId] = U.[Id]
						AND SW.[CampaignId] = UC.[CampaignId]
				WHERE GA.[VCC] = ''' + @VCC + '''
					AND GA.[ApplicationId] = ''supervisor''
				ORDER BY U.[Id] ASC, UC.[CampaignId] ASC 
		'
	END
	
	-- EJECUTAMOS LA CONSULTA
	EXEC(@SQL)
END
GO
PRINT N'Modificando [dbo].[GetEvaluations]...';


GO
ALTER PROCEDURE [dbo].[GetEvaluations] (
	@Instance Varchar(50) = NULL,
	@IdAuditor VARCHAR(MAX) = NULL,
	@IdAgent Varchar(MAX) = NULL,
   	@IdCampaign VARCHAR(MAX) = NULL,
	@IdEvaluationPlan VARCHAR(MAX) = NULL,
 	@EvaluationDateFrom VARCHAR(50) = '1980-01-01T00:00:00',
    @EvaluationDateTo VARCHAR(50) = '2050-01-01T23:59:59',
	@EvaluationHourFrom VARCHAR(50) = '00:00:00',
    @EvaluationHourTo VARCHAR(50) = '23:59:59',
	@InteractionMinDuration Int = 0,
    @InteractionMaxDuration Int = 86400,
    @InteractionOrigins Varchar(50) = NULL,
	@InteractionResults Varchar(MAX) = NULL,
	@EvaluationTypes Varchar(MAX) = NULL,
	@InteractionTags Varchar(MAX) = NULL,
	@InteractionFormats Varchar(50) = NULL,
	@InteractionCoached VARCHAR(50) = NULL,
	@InteractionIds     VARCHAR(MAX) = NULL,
	@EvaluationsLimit Int = 0
)
AS
BEGIN
	SET NOCOUNT ON
	IF (@EvaluationHourFrom = '') SET @EvaluationHourFrom = '00:00:00';
	IF (@EvaluationHourTo = '') SET @EvaluationHourTo = '23:59:59';
	
	-- SI ORIGINS TIENE DOS VALORES, IGNORAMOS EL FILTRO
	IF (SELECT COUNT(*) FROM [dbo].[split](@InteractionOrigins, ',')) = 2 SET @InteractionOrigins = ''
	
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = ''
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @SQL_FILTER VARCHAR(MAX) = ''
	DECLARE @SQL_EXTRA VARCHAR(MAX) = ''
	DECLARE @FILTERS_OPTIONAL_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_FIXED_PART     VARCHAR(MAX) = ''

	-- EMULAMOS UNA NUEVA TABLA EN BASE A INTERACTIONEVALUATIONPLAN
	SET @SQL_SELECT_1 += '
		;WITH CTE AS (
			SELECT ER.[Instance],
					ER.[IdEvaluationPlan],
					ER.[IdInteraction], 
					ER.[IdAgent],
					IEP.[AgentName],
					RN = ROW_NUMBER() OVER(PARTITION BY IEP.[Instance], IEP.[IdEvaluationPlan], IEP.[IdInteraction] ORDER BY IEP.[CreatedDate] ASC)
				FROM [dbo].[EvaluationResult] ER (NOLOCK) 
				INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
					ON EP.[Instance] = ER.[Instance]
						AND EP.[Id] =  ER.[IdEvaluationPlan]
				INNER JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
					ON (AEP.[Instance] = ER.[Instance] 
						AND AEP.[IdAuditor] = ER.[IdAuditor] 
						AND AEP.[IdInteraction] = ER.[IdInteraction] 
						AND AEP.[InteractionType] = ER.[InteractionType] 
						AND AEP.[IdEvaluationPlan] = ER.[IdEvaluationPlan]) 
				INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
					ON IEP.[Instance] = ER.[Instance] 
						AND IEP.[IdEvaluationPlan] = EP.[ID]
						AND IEP.[IdInteraction] = ER.[IdInteraction]
						AND IEP.[IdAgent] = ER.[IdAgent]
				WHERE ER.[Instance] = ''' + @Instance + '''
					AND ER.[EvaluationDate] BETWEEN ''' + @EvaluationDateFrom + '''AND ''' + @EvaluationDateTo + '''
					AND EP.[Status] = CASE EP.[Evaluation_Mode] WHEN ''A'' THEN 7 ELSE EP.[Status] END 
					AND AEP.[Completed] = 1
		) '

	SET @SQL_SELECT_1 += '
		SELECT '

	SET @SQL_SELECT_1 += '
				AEP.Completed						''completed'',
				AEP.[StatusDescription]             ''statusDescription'',
				A.[ErrorMessage]                    ''errorMessage'',
    			AEP.score							''qualification'',
    			AEP.IdAuditor						''idAuditor'',
    			U.FirstName + '' '' + U.LastName	''auditorName'',
    			MAX(ER.EvaluationDate)				''evaluationDate'',
    			AEP.IdEvaluationPlan				''idEvaluationPlan'',
				EP.Description						''evaluationPlan'',
    			AEP.idAgent							''idAgent'',
    			C.[AgentName]						''agentName'',							-- NOMBRE DEL AGENTE
				AEP.idInteraction					''idInteraction'',
				AEP.InteractionDate					''interactionDate'',
    			AEP.InteractionType					''interactionType'',
    			AEP.IdCampaign						''idCampaign'',
				COUNT(ERC.[Id])						''commitments'' '

	SET @SQL_FROM += '
			FROM EvaluationResult ER (NOLOCK) 
			LEFT JOIN [EvaluationPlan] EP (NOLOCK) 
				ON (EP.[Instance] = ER.[Instance] 
					AND EP.[ID] = ER.IdEvaluationPlan) 
			LEFT JOIN [AuditorEvaluationPlan] AEP (NOLOCK) 
				ON (AEP.[Instance] = ER.[Instance] 
					AND AEP.[IdAuditor] = ER.[IdAuditor] 
					AND AEP.[IdInteraction] = ER.[IdInteraction] 
					AND AEP.[InteractionType] = ER.[InteractionType] 
					AND AEP.[IdEvaluationPlan] = ER.[IdEvaluationPlan]) 
			LEFT JOIN [dbo].[EvaluationReviewCommitment] ERC (NOLOCK)
				ON ERC.[VCC] = AEP.[Instance] 
					AND ERC.[EvaluationPlanId] = AEP.[IdEvaluationPlan]
					AND ERC.[InteractionId] = AEP.[IdInteraction]
					AND ERC.[SupervisorId] = AEP.[IdAuditor] 
					AND ERC.[AgentId] = AEP.[idAgent]
			LEFT JOIN [dbo].[Audio] A (NOLOCK)
			    ON A.[VCC] = AEP.[Instance]
			        AND A.[ID] = AEP.[IdInteraction]
			LEFT JOIN [User] U (NOLOCK) 
				ON (U.[VCC] = ER.[Instance] 
					AND U.ID = AEP.IdAuditor) 
			LEFT JOIN CTE C (NOLOCK) 
				ON C.[Instance] = ER.[Instance]
					AND C.[IdEvaluationPlan] = ER.[IdEvaluationPlan]
					AND C.[IdInteraction] = ER.[IdInteraction] 
					AND C.[IdAgent] = ER.[IdAgent] 
					AND C.RN = 1 '

	SET @FILTERS_FIXED_PART = '
			WHERE ER.[Instance] = ''' + @Instance + '''
				AND ER.[EvaluationDate] >= ''' + @EvaluationDateFrom + '''
				AND ER.[EvaluationDate] <= ''' + @EvaluationDateTo + '''
				AND EP.[Status] = CASE EP.[Evaluation_Mode] WHEN ''A'' THEN 7 ELSE EP.[Status] END 
				AND AEP.[Completed] = 1 ' -- LINEA PARA FILTRAR EVALUACIONES COMPLETADAS

	IF (@IdAuditor IS NOT NULL AND @IdAuditor != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdAuditor] IN (SELECT Value FROM [dbo].[split](''' + @IdAuditor + ''','','')) '
	IF (@IdAgent IS NOT NULL AND @IdAgent != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdAgent] IN (SELECT Value FROM [dbo].[split](''' + @IdAgent + ''','','')) '
	IF (@IdCampaign IS NOT NULL AND @IdCampaign != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @IdCampaign + ''','','')) '
	IF (@IdEvaluationPlan IS NOT NULL AND @IdEvaluationPlan != '') SET @FILTERS_OPTIONAL_PART += 'AND EP.[ID] IN (SELECT Value FROM [dbo].[split](''' + @IdEvaluationPlan + ''','','')) '
	IF (CAST(@EvaluationHourFrom AS TIME) <= CAST(@EvaluationHourTo AS TIME)) SET @FILTERS_OPTIONAL_PART += 'AND CAST(ER.[EvaluationDate] AS TIME) BETWEEN ''' + @EvaluationHourFrom + ''' AND ''' + @EvaluationHourTo + ''' '
	IF (CAST(@EvaluationHourFrom AS TIME) > CAST(@EvaluationHourTo AS TIME)) SET @FILTERS_OPTIONAL_PART += 'AND CAST(ER.[EvaluationDate] AS TIME) NOT BETWEEN ''' + @EvaluationHourTo + ''' AND ''' + @EvaluationHourFrom + ''' '
	IF (@InteractionMinDuration IS NOT NULL) SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionDuration] >= ' + (SELECT CONVERT(varchar(10), @InteractionMinDuration)) + ' '
	IF (@InteractionMaxDuration IS NOT NULL) SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionDuration] <= ' + (SELECT CONVERT(varchar(10), @InteractionMaxDuration))+ ' '
	IF (@InteractionOrigins IS NOT NULL AND @InteractionOrigins != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionOrigin] IN (SELECT Value FROM [dbo].[split](''' + @InteractionOrigins + ''','','')) '
	--IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') SET @FILTERS_OPTIONAL_PART += 'AND CONCAT(AEP.[IdCampaign], ''_'', AEP.[ManagementResult]) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')) '
	IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') 
		SET @FILTERS_OPTIONAL_PART += 'AND (
								(CONCAT(AEP.[IdCampaign], ISNULL(REPLACE(AEP.[ManagementResult], ''/'', ''_''), ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(CONCAT(AEP.[IdCampaign], ''_'', ISNULL(AEP.[ManagementResult], ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(AEP.[ManagementResult] IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
							)'
	
	IF (@EvaluationTypes IS NOT NULL AND @EvaluationTypes != '') 
	BEGIN
		SET @FILTERS_OPTIONAL_PART += '
				AND EP.[Evaluation_Mode] IN (SELECT Value FROM [dbo].[split](''' + @EvaluationTypes + ''','',''))  '
	END;
	IF (@InteractionTags IS NOT NULL AND @InteractionTags != '') 
	BEGIN
		SET @SQL_FROM += '
			LEFT JOIN [Tag] T (NOLOCK) 
				ON (T.[VCC] = ER.[Instance] 
					AND T.[Tag] IN (SELECT Value FROM [dbo].[split](''' + @InteractionTags + ''','',''))) '
		SET @FILTERS_OPTIONAL_PART += '
				AND T.[AudioId] LIKE CONCAT(AEP.[IdInteraction], ''%'') 
				AND T.[AudioId] IS NOT NULL '
	END
	
	--IF (@InteractionFormats IS NOT NULL AND @InteractionFormats != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionFormat] IN (SELECT Value FROM [dbo].[split](''' + @InteractionFormats + ''','','')) '

	IF (@InteractionIds IS NOT NULL AND @InteractionIds <> '')
    BEGIN
        SET @FILTERS_OPTIONAL_PART = ''
	    SET @FILTERS_EXCLUDING_PART += ' AND AEP.[IdInteraction] IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')) '
	END

	SET @SQL_EXTRA += '
			GROUP BY AEP.Completed,
						AEP.[StatusDescription],
						A.[ErrorMessage],
						AEP.score,
						AEP.IdAuditor,
						U.FirstName + '' '' + U.LastName,
						AEP.IdEvaluationPlan,
						EP.Description,
						AEP.idAgent,
						C.[AgentName],
						AEP.idInteraction,
						AEP.InteractionDate,
						AEP.InteractionType,
						AEP.IdCampaign '

	IF @InteractionCoached IS NOT NULL AND @InteractionCoached != ''
	BEGIN
		IF @InteractionCoached = 'true'
			SET @SQL_EXTRA += '
				HAVING COUNT(ERC.[Id]) >= 1 '
		ELSE 
			SET @SQL_EXTRA += '
				HAVING COUNT(ERC.[Id]) = 0 '
	END

	SET @SQL_EXTRA += '
			ORDER BY MAX(ER.EvaluationDate) DESC '

	SET @SQL_SELECT_1 += @SQL_FROM  + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART + @SQL_EXTRA 

	-- SELECT @SQL_SELECT_1
	EXEC (@SQL_SELECT_1)
	
END
GO
PRINT N'Modificando [dbo].[GetI6InteractionAudios]...';


GO
ALTER PROCEDURE [dbo].[GetI6InteractionAudios] (
	@VCC					VARCHAR(50) = NULL,
	@InteractionId			VARCHAR(250) = NULL
) AS 
BEGIN
	-- DECLARAMOS VARIABLES PARA ALMACENAR LAS CANTIDADES DE REGISTROS
	DECLARE @AUDIO_RECORDS INT = 0
	DECLARE @INTERACION_EVALUATION_PLAN_RECORDS INT = 0

	SELECT @AUDIO_RECORDS = COUNT(*)
		FROM [dbo].[Audio] A (NOLOCK)
		WHERE A.[VCC] = @VCC
			AND A.[ID] = @InteractionId

	SELECT @INTERACION_EVALUATION_PLAN_RECORDS = COUNT(DISTINCT CONCAT(IEP.[IdInteraction], '_', IEP.[InteractionSection], '_', IEP.[InteractionPart]))
		FROM [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
		WHERE IEP.[Instance] = @VCC	
			AND IEP.[IdInteraction] = @InteractionId

	IF @AUDIO_RECORDS >= @INTERACION_EVALUATION_PLAN_RECORDS
	BEGIN

		-- BUSCAMOS LOS AUDIOS DE LA INTERACCION
		SELECT [ID]									'id',
				[Section]							'section',
				[Part]								'part',
				[Agent]								'agent',
				[Format]							'format'
			FROM [dbo].[Audio] A (NOLOCK)
			WHERE A.[VCC] = @VCC
				AND A.[ID] = @InteractionId
			ORDER BY A.[Section] ASC,  A.[Part] ASC
	END
	ELSE
	BEGIN
		SELECT [IdInteraction]						'id',
				[InteractionSection]				'section',
				[InteractionPart]					'part',
				[IdAgent]							'agent',
				[InteractionFormat]					'format'
			FROM [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
			WHERE IEP.[Instance] = @VCC	
				AND IEP.[IdInteraction] = @InteractionId
			ORDER by IEP.[InteractionSection] ASC, IEP.[InteractionPart] ASC
	END
END
GO
PRINT N'Modificando [dbo].[GetEvaluationReview]...';


GO
ALTER PROCEDURE [dbo].[GetEvaluationReview] (
	@VCC Varchar(50) = NULL, 
	@EvaluationPlanId VARCHAR(50) = NULL,
	@InteractionId VARCHAR(50) = NULL,
	@SupervisorId VARCHAR(50) = NULL,
	@AgentId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON
	
	-- SELECCIONAMOS LOS CAMPOS DE LA TABLA EVALUATION-REVIEW
	SELECT ER.[VCC]													'vcc',
			ER.[EvaluationPlanId]									'evaluationPlanId',
			ER.[InteractionId]										'interactionId',
			ER.[SupervisorId]										'supervisorId',
			ER.[Review]												'review'
		FROM [dbo].[EvaluationReview] ER (NOLOCK) 
		WHERE ER.[VCC] = @VCC
			AND ER.[EvaluationPlanId] = @EvaluationPlanId
			AND ER.[InteractionId] = @InteractionId
			AND ER.[SupervisorId] = ISNULL(@SupervisorId, ER.[SupervisorId])

	-- SELECCIONAMOS LOS CAMPOS DE LA TABLA EVALUATION-REVIEW-COMMITMENT
	EXEC [dbo].[GetEvaluationReviewCommitments] @VCC, @EvaluationPlanId, @InteractionId, @SupervisorId, @AgentId
	/*
	SELECT ER.[EvaluationPlanId]									'evaluationPlanId',
			ER.[SupervisorId]										'supervisorId',
			ERC.[LargeInteractionId]								'largeInteractionId',
			ERC.[AgentId]											'agentId',
			ERC.[Commitment]										'commitment',
			ERC.[CreatedDate]										'eventDate',
			ERC.[CreatedDate]										'createdDate'
		FROM [dbo].[EvaluationReviewCommitment] ERC (NOLOCK) 
		INNER JOIN [dbo].[EvaluationReview] ER (NOLOCK)
			ON ER.[VCC] = ERC.[VCC]
				AND ER.[Id] = ERC.[EvaluationReviewId]
		WHERE ER.[VCC] = @VCC
			AND ER.[EvaluationPlanId] = @EvaluationPlanId
			AND ER.[InteractionId] = @InteractionId
			AND ER.[SupervisorId] = ISNULL(@SupervisorId, ER.[SupervisorId])
			AND ERC.[AgentId] = ISNULL(@AgentId, ERC.[AgentId])
		ORDER BY [ERC].[CreatedDate] DESC
	*/
	
	SET NOCOUNT OFF
END
GO
PRINT N'Actualización completada.';


GO
