PRINT N'Altering Function [dbo].[SaveHistoricEvaluationPlanData]...';
GO

ALTER PROCEDURE [dbo].[SaveHistoricEvaluationPlanData] (
	@VCC VARCHAR(50) = NULL,
	@EvaluationPlanId VARCHAR(50)=NULL,
	@FormatId VARCHAR(100) = NULL
) AS
BEGIN
	SET NOCOUNT ON

	-- DECLARAMOS UNA VARIABLE PARA LA MODALIDAD DEL PLAN
	DECLARE @EVALUATION_MODE VARCHAR(50) = NULL 
	SELECT @EVALUATION_MODE = [Evaluation_Mode] FROM [dbo].[EvaluationPlan] (NOLOCK) WHERE [ID] = @EvaluationPlanId

	-- REGISTRAMOS LA DATA DEL FORMATO DE EVALUACION
	INSERT INTO [dbo].[HistoricEvaluationFormat] 
		SELECT EF.[Instance],
				EF.[ID],
				EF.[Description],
				EF.[type],
				EF.[EnvironmentType],
				EF.[MinAutomaticQualification],
				EF.[MinQualificationAcceptable],
				EF.[ManagementFormURL],
				EF.[Enabled],
				EF.[templateId],
				@EvaluationPlanId
            FROM [dbo].[EvaluationFormat] EF (NOLOCK) 
            WHERE [ID] = @FormatId 
				AND [Instance] = @VCC


	-- 
	INSERT INTO [dbo].[HistoricAbilityEvaluationFormat]
		SELECT DISTINCT A.[Instance],
							A.[ID] ,
							A.[IdEvaluationFormat],
							A.[IdAbility],
							A.[IdGroup],
							A.[IdSubGroup],
							A.[Penalizes],
							A.[Score],
							A.[Order],
							A.[Conditional],
							@EvaluationPlanId
			FROM  [dbo].[AbilityEvaluationFormat] A (NOLOCK)
			JOIN [dbo].[EvaluationFormat] EF (NOLOCK)
				ON EF.[Instance] = A.[Instance] 
					AND EF.[ID] = A.[IdEvaluationFormat]
			WHERE EF.[ID] = @FormatId AND EF.[Instance] = @VCC

	--
	INSERT INTO [dbo].[HistoricEvaluationFormatCustomField]
		SELECT ECF.[VCC],
				ECF.[ID],
				ECF.[EvaluationFormatId],
				ECF.[CustomFieldId],
				ECF.[Order],
				@EvaluationPlanId
			FROM [dbo].[EvaluationFormatCustomField] ECF (NOLOCK)
			JOIN [dbo].[EvaluationFormat] EF (NOLOCK) 
				ON ECF.[VCC] = EF.[Instance] 
				AND ECF.[EvaluationFormatId] = EF.[ID]
			WHERE EF.[ID] = @FormatId AND EF.[Instance] = @VCC
			GROUP BY ECF.[VCC],
						ECF.[ID],
						ECF.[EvaluationFormatId],
						ECF.[CustomFieldId],
						ECF.[Order]

	-- 
	INSERT INTO [dbo].[HistoricCustomField]
		SELECT C.[VCC],
				 C.[ID],
				 C.[Description],
				 C.[Type],
				 C.[Label],
				 @EvaluationPlanId
			FROM [dbo].[CustomField] C (NOLOCK)
			JOIN [dbo].[EvaluationFormatCustomField] FC (NOLOCK)
				ON C.[VCC] = FC.[VCC] 
					AND C.[ID] = FC.[CustomFieldId]
			WHERE FC.[EvaluationFormatId] = @FormatId 
				AND FC.[VCC] = @VCC
			GROUP BY C.[VCC],
						C.[ID],
						C.[Description],
						C.[Type],
						C.[Label]


	--
	INSERT INTO [dbo].[HistoricCustomFieldResult]
		SELECT CR.[VCC],
				CR.[ID],
				CR.[Description],
				CR.[Order],
				CR.[CustomFieldId],
				@EvaluationPlanId
			FROM [dbo].[CustomFieldResult] CR (NOLOCK)
			JOIN [dbo].[CustomField] C (NOLOCK)
				ON CR.[VCC] = C.[VCC] 
					AND CR.[CustomFieldId] = C.[ID]
			JOIN [dbo].[EvaluationFormatCustomField] FC (NOLOCK)
				ON C.[VCC] = FC.[VCC] 
					AND C.[ID] = FC.[CustomFieldId]
			WHERE FC.[EvaluationFormatId] = @FormatId 
				AND FC.[VCC] = @VCC
			GROUP BY CR.[VCC],
						CR.[ID],
						CR.[Description],
						CR.[Order],
						CR.[CustomFieldId]
	
	
	--
	INSERT INTO [dbo].[HistoricEvaluationFormatAttachedSignature]
		SELECT AFS.[VCC],
				AFS.[Description],
				AFS.[Order],
				AFS.[EvaluationFormatId],
				@EvaluationPlanId
			FROM [dbo].[EvaluationFormatAttachedSignature] AFS (NOLOCK)
            WHERE AFS.[EvaluationFormatId] = @FormatId 
				AND AFS.[VCC] = @VCC


	--
	INSERT INTO [dbo].[HistoricCampaignEvaluationFormat]
		SELECT CEF.[Instance],
				CEF.[IdEvaluationFormat],
				CEF.[IdCampaign],
				@EvaluationPlanId
			FROM [dbo].[CampaignEvaluationFormat] CEF (NOLOCK) 
			WHERE CEF.[IdEvaluationFormat] = @FormatId 
				AND CEF.[Instance] = @VCC
			GROUP BY CEF.[Instance],
						CEF.[IdEvaluationFormat],
						CEF.[IdCampaign]


	--
	INSERT INTO [dbo].[HistoricGroup] 
		SELECT G.[Instance] ,
				G.[ID],
				G.[Description] ,
				G.[Enabled],
				@EvaluationPlanId
			FROM [dbo].[Group] G (NOLOCK)
			JOIN [dbo].[AbilityEvaluationFormat] A (NOLOCK)
				ON  A.[Instance] = G.[Instance] 
					AND A.[IdGroup] = G.[ID]
			WHERE A.[IdEvaluationFormat] = @FormatId 
				AND A.[Instance] = @VCC
			GROUP BY G.[Instance] ,
						G.[ID],
						G.[Description] ,
						G.[Enabled] 
	


	--
	INSERT INTO [dbo].[HistoricSubGroup] 
		SELECT G.[Instance] ,
				G.[ID],
				G.[Description] ,
				G.[Enabled],
				@EvaluationPlanId
			FROM [dbo].[SubGroup] G (NOLOCK)
			JOIN [dbo].[AbilityEvaluationFormat] A (NOLOCK)
				ON  A.[Instance] = G.[Instance] 
					AND A.[IdSubGroup] = G.[ID]
			WHERE A.[IdEvaluationFormat] = @FormatId 
				AND A.[Instance] = @VCC
			GROUP BY G.[Instance],
						G.[ID],
						G.[Description] ,
						G.[Enabled] 


	-- INSERTAMOS LA DATA DE LAS HABILIDADES
	INSERT INTO [dbo].[HistoricAbility] 
		SELECT A.[Instance],
				A.[ID],
				A.[Title],
				A.[Detail],
				A.[Type],
				A.[CalificationType],
				A.[Binary],
				A.[NotApply],
				A.[Distribute],
				A.[AcceptComments],
				A.[Enabled],
				A.[AnalysisType],
				A.[Query],
				A.[QueryName],
				A.[Language],
				A.[IsNegative],
				@EvaluationPlanId
			FROM [dbo].[Ability] A (NOLOCK)
			JOIN [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
				ON  A.[Instance] = AEF.[Instance] 
					AND AEF.[IdAbility] = A.[ID]
			WHERE AEF.[IdEvaluationFormat] = @FormatId 
				AND A.[Instance] = @VCC

	-- REGISTRAMOS LOS SCORES ASOCIADOS A LAS HABILIDADES DEL FORMATO DEL PLAN
	INSERT INTO [dbo].[HistoricScore] 
		SELECT DISTINCT S.[Instance], 
						S.[ID], 
						S.[IdAbility], 
						S.[Description], 
						S.[Value], 
						EP.[ID]
			FROM [dbo].[EvaluationPlan] EP (NOLOCK)
			LEFT JOIN [dbo].[AbilityEvaluationFormat] AEP (NOLOCK)
				ON AEP.[Instance] = EP.[Instance]
					AND AEP.[IdEvaluationFormat] = EP.[IdEvaluationFormat]
			LEFT JOIN [dbo].[Score] S (NOLOCK)
				ON S.[Instance] = EP.[Instance]
					AND S.[IdAbility] = AEP.[IdAbility]
			WHERE EP.[Instance] = @VCC
			   AND EP.[ID] = @EvaluationPlanId
				
	-- REGISTRAMOS LOS SCORE_TIPIFICATIONS ASOCIADOS A LAS HABILIDADES DEL FORMATO DEL PLAN
	INSERT INTO [dbo].[HistoricEvaluationFormatAbilityScoreTipification]
		SELECT [VCC],
				[EvaluationFormatId],
				[ScoreId],
				[ID],
				[Description],
				[Detail],
				[Order],
				GETUTCDATE(),
				NULL,
				@EvaluationPlanId
			FROM [dbo].[EvaluationFormatAbilityScoreTipification] (NOLOCK)
			WHERE [VCC] = @VCC
				AND [EvaluationFormatId] = @FormatId
				
	-- REGISTRAMOS LOS SCORE_TIPIFICATION_QUERIES ASOCIADOS A LAS HABILIDADES DEL FORMATO DEL PLAN
	INSERT INTO [dbo].[HistoricEvaluationFormatAbilityScoreTipificationQuery]
		SELECT [VCC],
				[EvaluationFormatId],
				[ScoreId],
				[TipificationId],
				[QueryId],
				[QueryContent],
				[AcceptancePercentage],
				GETUTCDATE(),
				NULL,
				@EvaluationPlanId
			FROM [dbo].[EvaluationFormatAbilityScoreTipificationQuery] (NOLOCK)
			WHERE [VCC] = @VCC
				AND [EvaluationFormatId] = @FormatId
				-- select * FROM [dbo].[EvaluationFormatAbilityScoreTipificationQuery] (NOLOCK)
	
	
	-- REGISTRAMOS TIPIFICACIONES DE 2DO Y TERCER NIVEL CUANDO EL PLAN NO ES AUTOMATIC
	IF @EVALUATION_MODE <> 'A' 
	BEGIN
		-- REGISTRAMOS LOS SCORE_TIPIFICATIONS_ITEMS ASOCIADOS A LAS HABILIDADES DEL FORMATO DEL PLAN
		INSERT INTO [dbo].[HistoricEvaluationFormatAbilityScoreTipificationItem]
			SELECT [VCC],
					[EvaluationFormatId],
					[ScoreId],
					[TipificationId],
					[ID],
					[SecondLevelItemId],
					[Description],
					[Order],
					GETUTCDATE(),
					NULL,
					@EvaluationPlanId
				FROM [dbo].[EvaluationFormatAbilityScoreTipificationItem] (NOLOCK)
				WHERE [VCC] = @VCC
					AND [EvaluationFormatId] = @FormatId
	END
				
	-- 
	INSERT INTO [dbo].[HistoricAbilityQuery]
		SELECT AQ.[ID],
				AQ.[VCC],
				AQ.[AbilityId],
				AQ.[QueryId],
				AQ.[QueryContent],
				AQ.[AcceptancePercentage],
				AQ.[Order],
				@EvaluationPlanId
			FROM [dbo].[AbilityQuery] AQ (NOLOCK)
			JOIN [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
			ON  AQ.[VCC] = AEF.[Instance] AND AEF.[IdAbility] = AQ.[AbilityId]
			WHERE AEF.[IdEvaluationFormat] = @FormatId AND AQ.[VCC] = @VCC
			GROUP BY 
				AQ.[ID],
				AQ.[VCC],
				AQ.[AbilityId],
				AQ.[QueryId],
				AQ.[QueryContent],
				AQ.[AcceptancePercentage],
				AQ.[Order]

	--
	INSERT INTO [dbo].[HistoricAbilityQueryEntity]
		SELECT AQE.[VCC],
				AQE.[AbilityQueryId],
				AQE.[EntityId],
				AQE.[EntityName],
				AQE.[AcceptancePercentage],
				AQE.[Order],
				@EvaluationPlanId
			FROM [dbo].[AbilityQueryEntity] AQE (NOLOCK)
			JOIN [dbo].[AbilityQuery] AQ (NOLOCK)
				ON AQ.[VCC] = AQE.[VCC] 
					AND AQE.[AbilityQueryId] = AQ.[ID]
			JOIN [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
				ON  AQ.[VCC] = AEF.[Instance] 
					AND AEF.[IdAbility] = AQ.[AbilityId]
			WHERE AQ.[VCC] = @VCC 
				AND AEF.[IdEvaluationFormat] = @FormatId
			GROUP BY AQE.[VCC],
						AQE.[AbilityQueryId],
						AQE.[EntityId],
						AQE.[EntityName],
						AQE.[AcceptancePercentage],
						AQE.[Order]

	SET NOCOUNT OFF
END


PRINT N'Altering Function [dbo].[GetAgentsFromEvaluation]...';
GO
-- ESTE SP RETORNA LOS AGENTES ASOCIADOS A EVALUACIONES
ALTER PROCEDURE [dbo].[GetAgentsFromEvaluation] 
(
	@VCC					VARCHAR(50) = NULL,
	@UserId					VARCHAR(50) = NULL,
	@Campaigns				VARCHAR(MAX) = NULL,
	@SearchType				VARCHAR(50) = NULL,
	@EfectivityMode			BIT = 0 
) 
AS
BEGIN
	-- DECLARAMOS UN CADENA PARA EL QUERY FINAL
	DECLARE @SQL_SELECT VARCHAR(MAX) = '';
	DECLARE @SQL_FROM VARCHAR(MAX) = '';
	DECLARE @SQL_FROM_EFECTIVITY VARCHAR(MAX) = '';
	DECLARE @SQL_FILTER VARCHAR(MAX) = '';
	DECLARE @SQL_FILTER_EFECTIVITY VARCHAR(MAX) = '';
	DECLARE @SQL_EXTRA VARCHAR(MAX) = '';

	-- ARMAMOS EL QUERY PARA HACER LA CONSULTA
	SET @SQL_SELECT += '
		SELECT DISTINCT IEP.[Instance]							''vcc'', 
						IEP.[IdAgent]							''userId'',
						IEP.[IdCampaign]						''campaignId'' '

	-- ARMAMOS LA PARTE DE TABLAS 
	SET @SQL_FROM += '
			FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
			INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				ON IEP.[Instance] = AEP.[Instance]
					AND IEP.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND IEP.[IdInteraction] = AEP.[IdInteraction] '
	SET @SQL_FROM_EFECTIVITY += '
			FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
			INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				ON IEP.[Instance] = AEP.[Instance]
					AND IEP.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND IEP.[IdInteraction] = AEP.[IdInteraction] 
			INNER JOIN (
				SELECT DISTINCT [VCC],
								[InteractionId],
								[AgentId],
								[EvaluationPlanId],
								[AuditorId] 
					FROM [dbo].[EvaluationResultEfectivity] (NOLOCK)
					WHERE  [VCC] = ''' + @VCC + ' '' AND 
						 [EfectivityStatus] IN (''' + 'CREATED' + '''' + ',' + '''' + 'DRAFT' + ''''+ ')' + '
			) AS ERE ON 
				(AEP.[Instance] = ERE.[VCC] 
					AND AEP.[IdEvaluationPlan] = ERE.[EvaluationPlanId]
					AND AEP.[IdInteraction] = ERE.[InteractionId])'	

	-- ARMAMOS LA PARTE DE FILTROS
	SET @SQL_FILTER += '
			WHERE AEP.[Instance] = ''' + @VCC + ''' '
	SET @SQL_FILTER_EFECTIVITY += '
			WHERE AEP.[Instance] = ''' + @VCC + ''' '

	-- ARMAMOS LA PARTE DE EXTRAS
	SET @SQL_EXTRA = '
			ORDER BY IEP.[IdAgent] ASC '

	-- FILTRAMOS SEGUN EL TIPO DE BUSQUEDA
	IF @SearchType = 'PENDING'
	BEGIN
		-- HACEMOS LA BUSQUEDA SOBRE LAS INTERACCIONES QUE NO HAN SIDO EVALUADAS
		SET @SQL_FILTER += '
			AND AEP.[Completed] = 0 '
	END
	ELSE IF @SearchType = 'HISTORY'
	BEGIN
		-- HACEMOS LA BUSQUEDA SOBRE LAS INTERACCIONES QUE YA HAN SIDO EVALUADAS
		SET @SQL_FILTER += '
			AND AEP.[Completed] = 1 '
	END

	-- DECLARAMOS UNA VARIABLE PARA ALMACENAR EL ROLE DEL USUARIO
	DECLARE @USER_ROLE VARCHAR(50) 
	SELECT TOP 1 @USER_ROLE = U.[Role] 
		FROM [dbo].[User] U (NOLOCK) 
		WHERE U.[VCC] = @VCC
			AND U.[ID] = @UserId

	-- FILTRAMOS SEGUN EL ROLE DEL USUARIO
	-- IF @RoleId = 'administrator, quality_admin'
	IF @USER_ROLE = 'quality_auditor'
	BEGIN
		-- HACEMOS LA BUSQUEDA SOBRE LAS INTERACCIONES AUDITADAS POR EL USUARIO
		SET @SQL_FILTER += '
			AND AEP.[IdAuditor] = ''' + @UserId + ''' '
		SET @SQL_FILTER_EFECTIVITY += '
			AND ERE.[AuditorId] = ''' + @UserId + ''' '
	END
	ELSE IF @USER_ROLE = 'quality_agent'
	BEGIN
		-- HACEMOS LA BUSQUEDA SOBRE LAS INTERACCIONES HECHAS POR EL USUARIO
		SET @SQL_FILTER += '
			AND AEP.[IdAgent] = ''' + @UserId + ''' '
	END

	-- FILTRAMOS SEGUN EL VALOR DE CAMPAIGNS
	IF @Campaigns IS NOT NULL AND @Campaigns <> ''
	BEGIN
		SET @SQL_FILTER += '
			AND AEP.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaigns + ''','','')) '
        SET @SQL_FILTER_EFECTIVITY += '
			AND AEP.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaigns + ''','','')) '
	END 

	-- UNIMOS LAS PARTES DEL QUERY
	IF (@EfectivityMode =1)
	SET @SQL_SELECT += @SQL_FROM_EFECTIVITY + @SQL_FILTER_EFECTIVITY + @SQL_EXTRA
	ELSE
	SET @SQL_SELECT += @SQL_FROM + @SQL_FILTER + @SQL_EXTRA
	
	-- EJECUTAMOS LA CONSULTA
	PRINT @SQL_SELECT
	EXEC (@SQL_SELECT)
		
END
